#
# spec file for package trigger-rally
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           trigger-rally
Version:        0.6.5
Release:        lp150.1.18
Summary:        Fast-paced single-player rally racing game
License:        GPL-2.0
Group:          Amusements/Games/Action/Race
Url:            http://trigger-rally.sourceforge.net/
Source0:        http://downloads.sourceforge.net/project/trigger-rally/trigger-%{version}/trigger-rally-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM https://sourceforge.net/p/trigger-rally/patches/14/
Source1:        %{name}.desktop
# PATCH-FEATURE-UPSTREAM https://sourceforge.net/p/trigger-rally/patches/15/
Source2:        %{name}.appdata.xml
Source99:       %{name}.changes
BuildRequires:  dos2unix
BuildRequires:  fdupes
%if %{?suse_version} > 1320
BuildRequires:  gcc-c++ >= 5.0
%else
BuildRequires:  gcc5-c++
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  physfs-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(freealut)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A 3D rally simulation with a physics engine for drifting, over 100 maps,
different terrain materials like dirt, asphalt, sand, ice etc. and various
weather, light and fog conditions. Most maps are equipped with spoken co-driver
notes and co-driver icons.

%prep
%setup -q
dos2unix doc/*.txt bin/*.defs
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE99}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g" src/PEngine/app.cpp src/Trigger/menu.cpp

%build
%if %{?suse_version} <= 1320
export CXX=g++-5 CC=gcc-5
%endif
make --directory=src prefix=%{_prefix} exec_prefix=%{_prefix} bindir=%{_bindir}

%install
%make_install --directory=src prefix=%{_prefix} exec_prefix=%{_prefix} bindir=%{_bindir}

%suse_update_desktop_file -i %{name}

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
ln -sf %{_datadir}/games/trigger-rally/icon/trigger-rally-icons.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/trigger-rally.svg

mkdir -p %{buildroot}%{_datadir}/appdata
install -Dm0644 %{S:2} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%fdupes %{buildroot}%{_datadir}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%{_bindir}/*
%{_datadir}/games/trigger-rally
%{_datadir}/applications/trigger-rally.desktop
%{_datadir}/icons/hicolor/scalable/apps/trigger-rally.svg
%{_datadir}/doc/trigger-rally/
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml

%changelog
* Fri Feb 17 2017 rpm@fthiessen.de
- Update to version 0.6.5
  * Fixed compilation error of "hiscore1.h" by C++11 compilers
  * Added 2 new events and 13 new single races (total 25 new races)
  * Added "road sign" option for map creators
  * Updated code to use TinyXML-2, SDL2 and SDL2_image
  * Improved code friendliness to Linux when searching for the
    default configuration file "trigger-rally.config.defs"
- Dropped upstream merged hiscore1.h.patch
- Upstream switched from SDL to SDL2, corrected BuildRequires.
- Fixed file-contains-date-and-time warning
* Sun Aug 28 2016 mailaender@opensuse.org
- Update to v0.6.4
  - Added recording of best times
  - Added unlocking of vehicles and events
  - Optimized game data for smaller size and faster loading
  - Added "Pause" key (default `P`)
  - Added "Recover At Checkpoint" key (default `Q`)
  - Added multiple laps option for map creators
  - Added time penalty for offroad driving
  - Improved the "AB" codriver voice
  - Fixed sound bug in the Windows version
  - Changed default resolution to native fullscreen
- Add an AppData file
- Fix line endings on text files
* Fri Mar 25 2016 mailaender@opensuse.org
- Update to v0.6.3
  - Improve menu and in-race OSD
  - Add codriver for 75%% of maps
  - Tweak terrain physics
  - Add many new maps
  - Change vehicle skins and presets
  - Made various minor code improvements
  - Fix compilation warnings
  - Add support for .obj textures
  - Include new .obj textures (disabled by default)
  - Add 6 new events and 23 new single races courtesy of Onsemeliot
  - Add several new textures
  - Replace most media content (textures, audio, fonts, etc.) with
    FOSS equivalents
  - New FOSS Trigger Rally icon
  - Many other changes (check SVN logs from about r48)
* Sat Jan  5 2013 joop.boonen@opensuse.org
- openal*-devel isn't a build requirement as it's a requirement
  of freealut-devel
* Mon May  7 2012 prusnak@opensuse.org
- use datadir for game data
* Sun May  6 2012 schaeferf.obs@googlemail.com
- Update to v0.6.0:
  * New (and old) contributed tracks and events
  * New Practice Mode
  * Paging on the Single Races screen to show all the available tracks
  * Option to show speedometer in KPH or MPH
  * Option to show digital speed on the speed dial ('hybrid' style)
  * Fading track comment and GO at race start
  * Freezing course time when passing through a checkpoint
  * Tweak menu colours for more contrast 4/07/2010
  * Removed splash screen delay
  * Updated contact email address
* Fri Mar  6 2009 schaeferf.obs@googlemail.com
- update to SVN-version (revision 5)
* Tue Mar  3 2009 prusnak@opensuse.org
- use system glew library (glew.patch)
* Sun Mar  1 2009 schaeferf.obs@googlemail.com
- Initial openSUSE package release (0.5.2.1)
